.. _user-reference:

#############################
Reference for content editors
#############################

.. note::

          This is a new section in the django CMS documentation, and a priority
          for the project. If you'd like to contribute to it, we'd love to hear
          from you - join us on `our friendly Slack group
          <https://www.django-cms.org/slack>`_.

.. toctree::
    :maxdepth: 2

    page_admin
    frontend

.. _django-cms-developers: https://groups.google.com/group/django-cms-developers
.. _freenode : http://freenode.net/
